/*
 * Copyright (c) 2008-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 *    
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *    
 *  * Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *  * Neither the name of Nokia Corporation nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *    
 *    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *    AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *    IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 *    FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *    DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 *    SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *    OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *    
 *    Description:  
 */

#ifndef __DBMSDOCUMENT_H__
#define __DBMSDOCUMENT_H__


#include <akndoc.h>

// Forward declarations
class CDBMSAppUi;
class CEikApplication;


/**
 * Class:      CDBMSDocument
 *
 * Discussion: An instance of class CDBMSDocument is the Document
 *             part of the AVKON application framework for the DBMS
 *             example application.
 */
class CDBMSDocument : public CAknDocument
    {
public:

    /**
     * Function:   NewL
     *
     * Discussion: Construct a CDBMSDocument for the AVKON application
     *             aApp using two phase construction, and return a pointer
     *             to the created object.
     *
     * Param:      aApp application creating this document
     *
     * Returns:    A pointer to the created instance of CDBMSDocument
     */
    static CDBMSDocument* NewL(CEikApplication& aApp);

    /**
     * Function:   ~CDBMSDocument
     *
     * Discussion: Destroy the object
     */
    ~CDBMSDocument();

private:

    /**
     * Function:   ConstructL
     *
     * Discussion: Perform the second phase construction of a
     *             CDBMSDocument object.
     */
    void ConstructL();

    /**
     * Function:   CDBMSDocument
     *
     * Discussion: Perform the first phase of two phase construction
     *
     * Param:      aApp application creating this document
     */
    CDBMSDocument(CEikApplication& aApp);

private: // From CAknDocument

    /**
     * Function:   CreateAppUiL
     *
     * Discussion: Create the AppUi object and return a pointer to it.
     *
     * Returns:    A pointer to the created instance of the AppUi
     */
    CEikAppUi* CreateAppUiL();
    };


#endif // __DBMSDOCUMENT_H__
